@@ -51,18 +51,27 @@ agora_rtc_conn_renew_token = agora_lib.agora_rtc_conn_renew_token
 agora_rtc_conn_renew_token.restype = AGORA_API_C_INT
 agora_rtc_conn_renew_token.argtypes = [AGORA_HANDLE, ctypes.c_char_p]
 
+#AGORA_API_C_INT agora_rtc_conn_enable_encryption(AGORA_HANDLE agora_rtc_conn, int enabled, const encryption_config* config);
+
+agora_rtc_conn_enable_encryption = agora_lib.agora_rtc_conn_enable_encryption
+agora_rtc_conn_enable_encryption.restype = AGORA_API_C_INT
+agora_rtc_conn_enable_encryption.argtypes = [AGORA_HANDLE, ctypes.c_int, ctypes.POINTER(EncryptionConfigInner)]
+
 
 class RTCConnection:
-    def __init__(self, conn_handle) -> None:
+    def __init__(self, conn_handle, is_low_delay: bool = False) -> None:
         self.conn_handle = conn_handle
         self.con_observer = None
         self.local_user = None
         self.local_user_handle = agora_rtc_conn_get_local_user(conn_handle)
         if self.local_user_handle:
             self.local_user = LocalUser(self.local_user_handle, self)
+        #added to set low delay mode
+        if is_low_delay == True: 
+            self.local_user.set_audio_scenario(AudioScenarioType.AUDIO_SCENARIO_CHORUS)
         # add to map
-        AgoraHandleInstanceMap().set_local_user_map(self.conn_handle, self)
-        AgoraHandleInstanceMap().set_con_map(self.conn_handle, self)
+        #AgoraHandleInstanceMap().set_local_user_map(self.conn_handle, self)
+        #AgoraHandleInstanceMap().set_con_map(self.conn_handle, self)
 
     #
     def connect(self, token: str, chan_id: str, user_id: str) -> int:
@@ -126,11 +135,27 @@ class RTCConnection:
 
     def get_local_user(self):
         return self.local_user
+   
+    def enable_encryption(self, enabled: int, config: EncryptionConfig) -> int:
+        """
+        Enables or disables encryption for the connection.
+
+        Args:
+            enabled (int): 1 to enable encryption, 0 to disable.
+            config (EncryptionConfig): The encryption configuration.
+
+        Returns:
+            int: The result of the operation. 0 if successful, otherwise an error code.
+        Note:
+            This method must be called before self.connect()
+        """
+        inner_config = EncryptionConfigInner.create(config)
+        return agora_rtc_conn_enable_encryption(self.conn_handle, enabled, ctypes.byref(inner_config))
 
     def release(self):
         # release local user map
         if self.conn_handle:
-            AgoraHandleInstanceMap().del_local_user_map(self.conn_handle)
+            #AgoraHandleInstanceMap().del_local_user_map(self.conn_handle)
             agora_rtc_conn_release(self.conn_handle)
         self.conn_handle = None
         self.local_user = None
